# Medl

Download your playlists from Spotify, Youtube, Youtube Music and more incoming...

Advantages :

- Easy-to-use
- Downloads album art, metadata and lyrics
- Tries to get the most accurate metadata and audio

*Inspired by the spotDL library*

## ToDos

- m3u playlist files
- ...